@@ -1218,3 +1218,18 @@ babl_space_is_cmyk (const Babl *space)
  * of Adobe Systems Incorporated in many countires.
  */
 
+void
+babl_space_get_rgb_luminance (const Babl *space,
+                              double     *red_luminance,
+                              double     *green_luminance,
+                              double     *blue_luminance)
+{
+  if (!space)
+    space = babl_space ("sRGB");
+  if (red_luminance)
+    *red_luminance = space->space.RGBtoXYZ[3];
+  if (green_luminance)
+    *green_luminance = space->space.RGBtoXYZ[4];
+  if (blue_luminance)
+    *blue_luminance = space->space.RGBtoXYZ[5];
+}
