@@ -577,6 +577,20 @@ void babl_space_get (const Babl *space,
                      const Babl **green_trc,
                      const Babl **blue_trc);
 
+/**
+ * babl_space_get_rgb_luminance:
+ * @space: a BablSpace
+ * @red_luminance: pointer to a double where red luminance factor is stored
+ * @green_luminance: pointer to a double where green luminance factor is stored
+ * @blue_luminance: pointer to a double where blue luminance factor is stored
+ *
+ * Retrieve the relevant RGB luminance constants for a babl space.
+ */
+void
+babl_space_get_rgb_luminance (const Babl *space,
+                              double     *red_luminance,
+                              double     *green_luminance,
+                              double     *blue_luminance);
 
 /**
  * babl_model_is:
